# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Module providing the CeseSurfaceMechvarsD3Plot class."""
import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.keyword_base import KeywordBase

class CeseSurfaceMechvarsD3Plot(KeywordBase):
    """DYNA CESE_SURFACE_MECHVARS_D3PLOT keyword"""

    keyword = "CESE"
    subkeyword = "SURFACE_MECHVARS_D3PLOT"

    def __init__(self, **kwargs):
        """Initialize the CeseSurfaceMechvarsD3Plot class."""
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "output quantity",
                        str,
                        0,
                        80,
                        **kwargs,
                    ),
                ],
            ),
        ]

    @property
    def output_quantity(self) -> typing.Optional[str]:
        """Get or set the Descriptive phrase for the mechanics surface variable to output for the LSPP user.
        """ # nopep8
        return self._cards[0].get_value("output quantity")

    @output_quantity.setter
    def output_quantity(self, value: str) -> None:
        """Set the output_quantity property."""
        self._cards[0].set_value("output quantity", value)

